window.Gleam.initSearch([{"doc":"handles","title":"handles","content":"[![Package Version](https://img.shields.io/hexpm/v/handles)](https://hex.pm/packages/handles)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/handles/)\n\n# handles\n\n`handles` is a templating language written in pure Gleam. Heavily inspired by [mustache](https://mustache.github.io/) and [Handlebars.js](https://github.com/handlebars-lang/handlebars.js).\n\n```sh\ngleam add handles\n```\n\n```gleam\nimport gleam/io\nimport handles\nimport handles/ctx\n\npub fn main() {\n  let assert Ok(template) = handles.prepare(&quot;Hello {{name}}&quot;)\n  let assert Ok(string) =\n    handles.run(template, ctx.Dict([ctx.Prop(&quot;name&quot;, ctx.Str(&quot;Oliver&quot;))], []))\n\n  io.debug(string)\n}\n```\n\n## Usage Documentation\n\n__Handles__ a is very simple templating language that consists of a single primitive, the &quot;tag&quot;.\nA tag starts with two open braces `{{`, followed by a string body, and ends with two closing braces `}}`.\nThere are three kinds of tags, [Property tags](#property-tags), [Block tags](#block-tags), and [Partial tags](#partial-tags).\n\n### Property tags\n\nA property tag is used to access properties passed into the template engine and insert them into the resulting string in-place of the property tag.\nValues accessed by a property tag must be of type `String`, `Int`, or `Float`, or it will result in a runtime error.\nAccessing a property which was not passed into the template engine will result in a runtime error.\n\nA property tag can refer to a nested property with `.` separating keys in nested dicts.\n\n```handlebars\n{{some.property.path}}\n```\n\nA property can also refer to the current context element by passing a single `.`.\n\n```handlebars\n{{.}}\n```\n\n### Block tags\n\nA block tag is used to temporarily alter the behavior of the templating engine.\nEach block tag have two variants; A start tag indicated by a leading `#` and a stop tag indicated by a leading `/`.\nA blocks start tag accepts a property accessor, while the end tag does not.\n\n#### if\n\n`if` blocks are used to conditionally _include_ parts of a templated based on the value of a property.\nValues accessed by an if block must be of type `Bool` or it will result in a runtime error.\nAccessing a property which was not passed into the template engine will result in a runtime error.\n\n```handlebars\n{{#if some.prop}}\n  {{name}}\n{{/if}}\n```\n\n#### unless\n\n`unless` blocks are used to conditionally _exclude_ parts of a templated based on the value of a property.\nValues accessed by an `unless` block must be of type `Bool` or it will result in a runtime error.\nAccessing a property which was not passed into the template engine will result in a runtime error.\n\n```handlebars\n{{#unless some.prop}}\n  {{name}}\n{{/unless}}\n```\n\n#### each\n\n`each` blocks are used to include a part of a templated zero or more times.\nValues accessed by an `each` block must be of type `List` or it will result in a runtime error.\nAccessing a property which was not passed into the template engine will result in a runtime error.\nThe context of which properties are resolved while inside the each block will be scoped to the current item from the list.\n\n```handlebars\n{{#each some.prop}}\n  {{name}}\n{{/each}}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/handles&gt;.\n\n### Partial tags\n\nA partial tag is used to include other templates in-place of the partial tag.\nValues accessed by a partial tag can be of any type and will be passed to the partial as the context of which properties are resolved against while inside the partial template.\nAccessing a property which was not passed into the template engine will result in a runtime error.\n\n```handlebars\n{{&gt;some_template some.prop.path}}\n```\n\n## Development\n\n```sh\ngleam test\n```\n","url":"index.html"},{"doc":"handles/ctx","title":"Prop","content":"pub type Prop {\n  Prop(key: String, value: Value)\n}\n\nProp(key: String, value: Value)\n\n\nSynonyms:\nhandles/ctx.Prop\nhandles/ctx Prop","url":"handles/ctx.html#Prop"},{"doc":"handles/ctx","title":"Value","content":"pub type Value {\n  Str(value: String)\n  Int(value: Int)\n  Float(value: Float)\n  Bool(value: Bool)\n  Dict(value: List(Prop))\n  List(value: List(Value))\n}\n\nStr(value: String)\n\n\nInt(value: Int)\n\n\nFloat(value: Float)\n\n\nBool(value: Bool)\n\n\nDict(value: List(Prop))\n\n\nList(value: List(Value))\n\n\nSynonyms:\nhandles/ctx.Value\nhandles/ctx Value","url":"handles/ctx.html#Value"},{"doc":"handles/ctx","title":"handles/ctx","content":"","url":"handles/ctx.html"},{"doc":"handles/error","title":"RuntimeError","content":"pub type RuntimeError {\n  UnexpectedType(\n    index: Int,\n    path: List(String),\n    got: String,\n    expected: List(String),\n  )\n  UnknownProperty(index: Int, path: List(String))\n  UnknownPartial(index: Int, id: String)\n}\n\nUnexpectedType(\n  index: Int,\n  path: List(String),\n  got: String,\n  expected: List(String),\n)\n\n\nUnknownProperty(index: Int, path: List(String))\n\n\nUnknownPartial(index: Int, id: String)\n\n\nSynonyms:\nhandles/error.RuntimeError\nhandles/error RuntimeError","url":"handles/error.html#RuntimeError"},{"doc":"handles/error","title":"TokenizerError","content":"pub type TokenizerError {\n  UnbalancedTag(index: Int)\n  MissingArgument(index: Int)\n  MissingBlockKind(index: Int)\n  MissingPartialId(index: Int)\n  UnexpectedMultipleArguments(index: Int)\n  UnexpectedArgument(index: Int)\n  UnexpectedBlockKind(index: Int)\n}\n\nUnbalancedTag(index: Int)\n\n\nMissingArgument(index: Int)\n\n\nMissingBlockKind(index: Int)\n\n\nMissingPartialId(index: Int)\n\n\nUnexpectedMultipleArguments(index: Int)\n\n\nUnexpectedArgument(index: Int)\n\n\nUnexpectedBlockKind(index: Int)\n\n\nSynonyms:\nhandles/error.TokenizerError\nhandles/error TokenizerError","url":"handles/error.html#TokenizerError"},{"doc":"handles/error","title":"handles/error","content":"","url":"handles/error.html"},{"doc":"handles","title":"Template","content":"pub opaque type Template\n\n\nSynonyms:\nhandles.Template\nhandles Template","url":"handles.html#Template"},{"doc":"handles","title":"prepare","content":"pub fn prepare(\n  template: String,\n) -&gt; Result(Template, TokenizerError)\n\nSynonyms:\nhandles.prepare\nhandles prepare","url":"handles.html#prepare"},{"doc":"handles","title":"run","content":"pub fn run(\n  template: Template,\n  ctx: Value,\n  partials: List(#(String, Template)),\n) -&gt; Result(String, RuntimeError)\n\nSynonyms:\nhandles.run\nhandles run","url":"handles.html#run"},{"doc":"handles","title":"handles","content":"","url":"handles.html"},{"doc":"handles/format","title":"format_runtime_error","content":"pub fn format_runtime_error(\n  error: RuntimeError,\n  template: String,\n) -&gt; Result(String, Nil)\n\nSynonyms:\nhandles/format.format_runtime_error\nhandles/format format_runtime_error","url":"handles/format.html#format_runtime_error"},{"doc":"handles/format","title":"format_tokenizer_error","content":"pub fn format_tokenizer_error(\n  error: TokenizerError,\n  template: String,\n) -&gt; Result(String, Nil)\n\nSynonyms:\nhandles/format.format_tokenizer_error\nhandles/format format_tokenizer_error","url":"handles/format.html#format_tokenizer_error"},{"doc":"handles/format","title":"handles/format","content":"","url":"handles/format.html"}]);